import { DocumentNode } from "graphql";
import { GraphQLSchema, FragmentDefinitionNode, OperationDefinitionNode, GraphQLType } from "graphql";
import { Maybe } from "graphql/jsutils/Maybe";
import { OperationData } from "./codegen/codegenHelpers";
export default function capitalizeFirstLetter(string: string): string;
declare type OutEnum = {
    kind: "enum";
    description?: Maybe<string>;
    values: string[];
};
declare type OutSelection = Record<string, OutSelectionFieldValue>;
declare type OutSelectionFieldValue = {
    kind: "selection_field";
    name: string;
    type: OutType;
    description?: Maybe<string>;
};
declare type OutInlineFragment = {
    kind: "inlineFragment";
    typeCondition: string;
    selections: OutSelection;
};
declare type OutObject = {
    kind: "object";
    description?: Maybe<string>;
    namedFragments: string[];
    inlineFragments: OutInlineFragment[];
    selections: OutSelection;
};
declare type OutArray = {
    kind: "array";
    description?: Maybe<string>;
    type: OutType;
};
declare type OutScalar = {
    kind: "scalar";
    description?: Maybe<string>;
    type: string;
};
declare type OutType = OutEnum | OutObject | OutArray | OutScalar;
export declare function gatherAllReferencedTypes(schema: GraphQLSchema, query: OperationDefinitionNode): Array<string>;
export declare function gatherVariableDefinitions(definition: OperationDefinitionNode): Array<[string, string]>;
export declare function typeScriptForGraphQLType(schema: GraphQLSchema, gqlType: GraphQLType): string;
export declare const guessVariableDescriptions: (schema: GraphQLSchema, operationDefinition: OperationDefinitionNode, variableNames: string[]) => Record<string, {
    usageCount: number;
    descriptions?: Set<string>;
}>;
export declare function typeScriptSignatureForOperationVariables(variableNames: Array<string>, schema: GraphQLSchema, operationDefinition: OperationDefinitionNode): string;
export declare function listCount(gqlType: any): number;
export declare function typeScriptDefinitionObjectForOperation(schema: GraphQLSchema, operationDefinition: OperationDefinitionNode | FragmentDefinitionNode, fragmentDefinitions: Record<string, FragmentDefinitionNode>): OutObject;
export declare function typeScriptSignatureForOperation(schema: GraphQLSchema, operationDefinition: OperationDefinitionNode, fragmentDefinitions: Record<string, FragmentDefinitionNode>): string;
export declare function typeScriptDefinitionObjectForFragment(schema: GraphQLSchema, fragmentDefinition: FragmentDefinitionNode, fragmentDefinitions: Record<string, FragmentDefinitionNode>, shouldLog?: boolean): OutObject | OutScalar;
export declare function typeScriptSignatureForFragment(schema: GraphQLSchema, fragmentDefinition: FragmentDefinitionNode, fragmentDefinitions: Record<string, FragmentDefinitionNode>): string;
export declare function typeScriptTypeNameForOperation(name: string): string;
/**
 * Doesn't patch e.g. fragments
 */
export declare function patchSubscriptionWebhookField({ schema, definition, }: {
    schema: GraphQLSchema;
    definition: OperationDefinitionNode;
}): OperationDefinitionNode;
export declare function patchSubscriptionWebhookSecretField({ schema, definition, }: {
    schema: GraphQLSchema;
    definition: OperationDefinitionNode;
}): OperationDefinitionNode;
export declare const formInput: (schema: any, def: any, path?: never[]) => string | null;
export declare const remixFormInput: (schema: any, def: any, path?: never[]) => string | null;
export declare const formElComponent: ({ operationData, schema, callFn, }: {
    operationData: OperationData;
    schema: GraphQLSchema;
    callFn: string;
}) => {
    formHelpers: string;
    formEl: string;
};
export declare const normalizeOperationsDoc: (operationsDoc: string) => string;
export declare const gatherHardcodedValues: (query: string) => [string, string | number][];
export declare const extractPersistableOperation: (doc: DocumentNode, operationDefinition: OperationDefinitionNode) => string | null;
export {};
